#ifndef sdm630m_registers_h
#define sdm630m_registers_h

#define SMD630M_NRVAL 85

// 85 Messwerte
static sdm_registers_t sdm630m_registers[] = {
	{ "L1-N Voltage",				"V"	,   0 },
	{ "L2-N Voltage",				"V"	,   2 },
	{ "L3-N Voltage",				"V"	,   4 },
	{ "L1 Current",					"A"	,   6 },
	{ "L2 Current",					"A"	,   8 },
	{ "L3 Current",					"A"	,  10 },
	{ "L1 Power",					"W"	,  12 },
	{ "L2 Power",					"W"	,  14 },
	{ "L3 Power",					"W"	,  16 },
	{ "L1 Apparent Power",				"VA"	,  18 },
	{ "L2 Apparent Power",				"VA"	,  20 },
	{ "L3 Apparent Power",				"VA"	,  22 },
	{ "L1 Reactive Power",				"VAr"	,  24 },
	{ "L2 Reactive Power",				"VAr"	,  26 },
	{ "L3 Reactive Power",				"VAr"	,  28 },
	{ "L1 Power Factor",				"1"	,  30 },
	{ "L2 Power Factor",				"1"	,  32 },
	{ "L3 Power Factor",				"1"	,  34 },
	{ "L1 Phase Angle",				"°"	,  36 },
	{ "L2 Phase Angle",				"°"	,  38 },
	{ "L3 Phase Angle",				"°"	,  40 },
	{ "Average Voltage",				"V"	,  42 },
	{ "Average Current",				"A"	,  46 },
	{ "Current (Sum)",				"A"	,  48 },
	{ "Total Power",				"W"	,  52 },
	{ "Total Apparent Power",			"VA"	,  56 },
	{ "Total Reactive Power",			"VAr"	,  60 },
	{ "Total Power Factor",				"1"	,  62 },
	{ "Total Phase Angle",				"°"	,  66 },
	{ "Frequency",					"Hz"	,  70 },
	{ "Energy Import",				"kWh"	,  72 },
	{ "Energy Export",				"kWh"	,  74 },
	{ "Reactive Energy Import",			"kVArh"	,  76 },
	{ "Reactive Energy Export",			"kVArh"	,  78 },
	{ "Total VAh",					"kVAh"	,  80 },
	{ "Total Ah",					"kAh"	,  82 },
	{ "Total Power Demand",				"W"	,  84 },
	{ "Total Power Demand (Max)",			"W"	,  86 },
	{ "Total Apparent Power Demand",		"VA"	, 100 },
	{ "Total Apparent Power Demand (Max)",		"VA"	, 102 },
	{ "Neutral Current Demand",			"A"	, 104 },
	{ "Neutral Current Demand (Max)",		"A"	, 106 },
	{ "L1-L2 Voltage",				"V"	, 200 },
	{ "L2-L3 Voltage",				"V"	, 202 },
	{ "L3-L1 Voltage",				"V"	, 204 },
	{ "Average Line-Line Voltage",			"V"	, 206 },
	{ "Neutral Current",				"A"	, 224 },
	{ "L1-N THD (U)",				"%"	, 234 },
	{ "L2-N THD (U)",				"%"	, 236 },
	{ "L3-N THD (U)",				"%"	, 238 },
	{ "L1 THD (I)",					"%"	, 240 },
	{ "L2 THD (I)",					"%"	, 242 },
	{ "L3 THD (I)",					"%"	, 244 },
	{ "Average THD (U)",				"%"	, 248 },
	{ "Average THD (I)",				"%"	, 250 },
	{ "L1 Current Demand",				"A"	, 258 },
	{ "L2 Current Demand",				"A"	, 260 },
	{ "L3 Current Demand",				"A"	, 262 },
	{ "L1 Current Demand (Max)",			"A"	, 264 },
	{ "L2 Current Demand (Max)",			"A"	, 266 },
	{ "L3 Current Demand (Max)",			"A"	, 268 },
	{ "L1-L2 THD (U)",				"%"	, 334 },
	{ "L2-L3 THD (U)",				"%"	, 336 },
	{ "L3-L1 THD (U)",				"%"	, 338 },
	{ "Average L-L THD",				"%"	, 340 },
	{ "Total Energy",				"kWh"	, 342 },
	{ "Total Reactive Energy",			"kVArh"	, 344 },
	{ "L1 Energy Import",				"kWh"	, 346 },
	{ "L2 Energy Import",				"kWh"	, 348 },
	{ "L3 Energy Import",				"kWh"	, 350 },
	{ "L1 Energy Export",				"kWh"	, 352 },
	{ "L2 Energy Export",				"kWh"	, 354 },
	{ "L3 Energy Export",				"kWh"	, 356 },
	{ "L1 Energy (Total)",				"kWh"	, 358 },
	{ "L2 Energy (Total)",				"kWh"	, 360 },
	{ "L3 Energy (Total)",				"kWh"	, 362 },
	{ "L1 Reactive Energy Import",			"kVArh"	, 364 },
	{ "L2 Reactive Energy Import",			"kVArh"	, 366 },
	{ "L3 Reactive Energy Import",			"kVArh"	, 368 },
	{ "L1 Reactive Energy Export",			"kVArh"	, 370 },
	{ "L2 Reactive Energy Export",			"kVArh"	, 372 },
	{ "L3 Reactive Energy Export",			"kVArh"	, 374 },
	{ "L1 Reactive Energy (Total)",			"kVArh"	, 376 },
	{ "L2 Reactive Energy (Total)",			"kVArh"	, 378 },
	{ "L3 Reactive Energy (Total)",			"kVArh"	, 380 },
	{ NULL,						NULL	,   0 }
};
#endif
